@@ -211,7 +211,7 @@ void Bmatch_help(void)
     "#!/bin/tcsh\n"
     "\n"
     "# optional: start a virtual X11 server\n"
-    "  set xdisplay = `count -dig 1 3 999 R1`\n"
+    "  set xdisplay = `count_afni -dig 1 3 999 R1`\n"
     "  echo \" -- trying to start Xvfb :${xdisplay}\"\n"
     "  Xvfb :${xdisplay} -screen 0 1024x768x24 >& /dev/null &\n"
     "  sleep 1\n"
@@ -280,7 +280,7 @@ void Bmatch_help(void)
     "#!/bin/tcsh\n"
     "\n"
     "# optional: start Xvfb to avoid the AFNI GUI starting visibly\n"
-    "  set xdisplay = `count -dig 1 3 999 R1`\n"
+    "  set xdisplay = `count_afni -dig 1 3 999 R1`\n"
     "  echo \" -- trying to start Xvfb :${xdisplay}\"\n"
     "  Xvfb :${xdisplay} -screen 0 1024x768x24 >& /dev/null &\n"
     "  sleep 1\n"
