@@ -1535,7 +1535,7 @@ void lightenActiveClipPlaneSquare(int planeIndex){
 
        // switch to the recently loaded  cmap
         SUMA_COLOR_MAP *Cmp = SUMA_FindNamedColMap ("ngray20");
-        Cmp->idvec = SO->idcode_str;
+        /* Cmp->idvec = SO->idcode_str; */
         if (!SUMA_SwitchColPlaneCmap(ado, Cmp)) {
             fprintf(stderr, "Failed in SUMA_SwitchColPlaneCmap");
             return;
@@ -1593,7 +1593,7 @@ void lightenActiveClipPlaneSquare(int planeIndex){
 
        // switch to the recently loaded  cmap
         SUMA_COLOR_MAP *Cmp = SUMA_FindNamedColMap ("ngray20");
-        Cmp->idvec = SO->idcode_str;
+        /* Cmp->idvec = SO->idcode_str; */
         if (SUMAg_CF->clippingPlaneVerbose && SUMAg_CF->clippingPlaneVerbosityLevel>1)
         {
             fprintf(stderr, "### Darken clipping plane square: switch to the recently loaded  cmap\n");
