@@ -343,10 +343,10 @@ int apsearch_usage(TFORM targ, int detail)
 "\n"
 "Examples:\n"
 "=========\n"
-" 1- Search help output of program whereami for the word '-atlas'\n"
-"        apsearch -ci -phelp whereami -word -atlas\n"
+" 1- Search help output of program whereami_afni for the word '-atlas'\n"
+"        apsearch -ci -phelp whereami_afni -word -atlas\n"
 " 2- Search all atlas area names for some name (mistakes on purpose)\n"
-"        whereami -show_atlas_code > all_atlas_area_names.txt\n"
+"        whereami_afni -show_atlas_code > all_atlas_area_names.txt\n"
 "        apsearch -file all_atlas_area_names.txt -word hepp\n"
 "        apsearch -file all_atlas_area_names.txt -word zipp \\\n"
 "                  -min_different_hits 5 -unique_hits_only \n"
@@ -367,11 +367,11 @@ int apsearch_usage(TFORM targ, int detail)
 "        apsearch -all_popts 3dSkullStrip\n"
 "    (*) see -all_popts in help section\n"
 " 7- Look for some area named something or other in some atlas:\n"
-"        whereami -show_atlas_code -atlas DKD_Desai_MPM |\\\n"
+"        whereami_afni -show_atlas_code -atlas DKD_Desai_MPM |\\\n"
 "                                apsearch -stdin -word insola\n"
 "    If you really screw up the spelling, you should help the search\n"
 "    program a little as in:\n"
-"        whereami -show_atlas_code -atlas DKD_Desai_MPM |\\\n"
+"        whereami_afni -show_atlas_code -atlas DKD_Desai_MPM |\\\n"
 "                                sed 's/[-_]/ /g' |\\\n"
 "                                apsearch -stdin -word insolent\n"
 " 8- Find 10 afni programs with something like 'Surface' in their names:\n"
