@@ -533,185 +533,187 @@ static char CB_CS[] = {
 /*
   [PT: July 4, 2022] Add these colorbars in hex here (some exist as
   floats in pbardefs_float.h); mainly for SUMA usage
+  [PT: May 23, 2024] Ummm, these (GoogleTurbo, Inferno, Magma, Plasma 
+  and Viridis) were backwards originally.
 */
 static char HEX_GoogleTurbo_256_CMD[] = {
     "GoogleTurbo "
-    "#30123b #311542 #32184a #341b51 #351e58 #36215f #372365 #38266c "
-    "#392972 #3a2c79 #3b2f7f #3c3285 #3c358b #3d3791 #3e3a96 #3f3d9c "
-    "#4040a1 #4043a6 #4145ab #4148b0 #424bb5 #434eba #4350be #4353c2 "
-    "#4456c7 #4458cb #455bce #455ed2 #4560d6 #4563d9 #4666dd #4668e0 "
-    "#466be3 #466de6 #4670e8 #4673eb #4675ed #4678f0 #467af2 #467df4 "
-    "#467ff6 #4682f8 #4584f9 #4587fb #4589fc #448cfd #438efd #4291fe "
-    "#4193fe #4096fe #3f98fe #3e9bfe #3c9dfd #3ba0fc #39a2fc #38a5fb "
-    "#36a8f9 #34aaf8 #33acf6 #31aff5 #2fb1f3 #2db4f1 #2bb6ef #2ab9ed "
-    "#28bbeb #26bde9 #25c0e6 #23c2e4 #21c4e1 #20c6df #1ec9dc #1dcbda "
-    "#1ccdd7 #1bcfd4 #1ad1d2 #19d3cf #18d5cc #18d7ca #17d9c7 #17dac4 "
-    "#17dcc2 #17debf #18e0bd #18e1ba #19e3b8 #1ae4b6 #1be5b4 #1de7b1 "
-    "#1ee8af #20e9ac #22eba9 #24eca6 #27eda3 #29eea0 #2cef9d #2ff09a "
-    "#32f197 #35f394 #38f491 #3bf48d #3ff58a #42f687 #46f783 #4af880 "
-    "#4df97c #51f979 #55fa76 #59fb72 #5dfb6f #61fc6c #65fc68 #69fd65 "
-    "#6dfd62 #71fd5f #74fe5c #78fe59 #7cfe56 #80fe53 #84fe50 #87fe4d "
-    "#8bfe4b #8efe48 #92fe46 #95fe44 #98fe42 #9bfd40 #9efd3e #a1fc3d "
-    "#a4fc3b #a6fb3a #a9fb39 #acfa37 #aef937 #b1f836 #b3f835 #b6f735 "
-    "#b9f534 #bbf434 #bef334 #c0f233 #c3f133 #c5ef33 #c8ee33 #caed33 "
-    "#cdeb34 #cfea34 #d1e834 #d4e735 #d6e535 #d8e335 #dae236 #dde036 "
-    "#dfde36 #e1dc37 #e3da37 #e5d838 #e7d738 #e8d538 #ead339 #ecd139 "
-    "#edcf39 #efcd39 #f0cb3a #f2c83a #f3c63a #f4c43a #f6c23a #f7c039 "
-    "#f8be39 #f9bc39 #f9ba38 #fab737 #fbb537 #fbb336 #fcb035 #fcae34 "
-    "#fdab33 #fda932 #fda631 #fda330 #fea12f #fe9e2e #fe9b2d #fe982c "
-    "#fd952b #fd9229 #fd8f28 #fd8c27 #fc8926 #fc8624 #fb8323 #fb8022 "
-    "#fa7d20 #fa7a1f #f9771e #f8741c #f7711b #f76e1a #f66b18 #f56817 "
-    "#f46516 #f36315 #f26014 #f15d13 #ef5a11 #ee5810 #ed550f #ec520e "
-    "#ea500d #e94d0d #e84b0c #e6490b #e5460a #e3440a #e24209 #e04008 "
-    "#de3e08 #dd3c07 #db3a07 #d93806 #d73606 #d63405 #d43205 #d23005 "
-    "#d02f04 #ce2d04 #cb2b03 #c92903 #c72803 #c52602 #c32402 #c02302 "
-    "#be2102 #bb1f01 #b91e01 #b61c01 #b41b01 #b11901 #ae1801 #ac1601 "
-    "#a91501 #a61401 #a31201 #a01101 #9d1001 #9a0e01 #970d01 #940c01 "
-    "#910b01 #8e0a01 #8b0901 #870801 #840701 #810602 #7d0502 #7a0402 "
+    "#7a0402 #7d0502 #810602 #840701 #870801 #8b0901 #8e0a01 #910b01 "
+    "#940c01 #970d01 #9a0e01 #9d1001 #a01101 #a31201 #a61401 #a91501 "
+    "#ac1601 #ae1801 #b11901 #b41b01 #b61c01 #b91e01 #bb1f01 #be2102 "
+    "#c02302 #c32402 #c52602 #c72803 #c92903 #cb2b03 #ce2d04 #d02f04 "
+    "#d23005 #d43205 #d63405 #d73606 #d93806 #db3a07 #dd3c07 #de3e08 "
+    "#e04008 #e24209 #e3440a #e5460a #e6490b #e84b0c #e94d0d #ea500d "
+    "#ec520e #ed550f #ee5810 #ef5a11 #f15d13 #f26014 #f36315 #f46516 "
+    "#f56817 #f66b18 #f76e1a #f7711b #f8741c #f9771e #fa7a1f #fa7d20 "
+    "#fb8022 #fb8323 #fc8624 #fc8926 #fd8c27 #fd8f28 #fd9229 #fd952b "
+    "#fe982c #fe9b2d #fe9e2e #fea12f #fda330 #fda631 #fda932 #fdab33 "
+    "#fcae34 #fcb035 #fbb336 #fbb537 #fab737 #f9ba38 #f9bc39 #f8be39 "
+    "#f7c039 #f6c23a #f4c43a #f3c63a #f2c83a #f0cb3a #efcd39 #edcf39 "
+    "#ecd139 #ead339 #e8d538 #e7d738 #e5d838 #e3da37 #e1dc37 #dfde36 "
+    "#dde036 #dae236 #d8e335 #d6e535 #d4e735 #d1e834 #cfea34 #cdeb34 "
+    "#caed33 #c8ee33 #c5ef33 #c3f133 #c0f233 #bef334 #bbf434 #b9f534 "
+    "#b6f735 #b3f835 #b1f836 #aef937 #acfa37 #a9fb39 #a6fb3a #a4fc3b "
+    "#a1fc3d #9efd3e #9bfd40 #98fe42 #95fe44 #92fe46 #8efe48 #8bfe4b "
+    "#87fe4d #84fe50 #80fe53 #7cfe56 #78fe59 #74fe5c #71fd5f #6dfd62 "
+    "#69fd65 #65fc68 #61fc6c #5dfb6f #59fb72 #55fa76 #51f979 #4df97c "
+    "#4af880 #46f783 #42f687 #3ff58a #3bf48d #38f491 #35f394 #32f197 "
+    "#2ff09a #2cef9d #29eea0 #27eda3 #24eca6 #22eba9 #20e9ac #1ee8af "
+    "#1de7b1 #1be5b4 #1ae4b6 #19e3b8 #18e1ba #18e0bd #17debf #17dcc2 "
+    "#17dac4 #17d9c7 #18d7ca #18d5cc #19d3cf #1ad1d2 #1bcfd4 #1ccdd7 "
+    "#1dcbda #1ec9dc #20c6df #21c4e1 #23c2e4 #25c0e6 #26bde9 #28bbeb "
+    "#2ab9ed #2bb6ef #2db4f1 #2fb1f3 #31aff5 #33acf6 #34aaf8 #36a8f9 "
+    "#38a5fb #39a2fc #3ba0fc #3c9dfd #3e9bfe #3f98fe #4096fe #4193fe "
+    "#4291fe #438efd #448cfd #4589fc #4587fb #4584f9 #4682f8 #467ff6 "
+    "#467df4 #467af2 #4678f0 #4675ed #4673eb #4670e8 #466de6 #466be3 "
+    "#4668e0 #4666dd #4563d9 #4560d6 #455ed2 #455bce #4458cb #4456c7 "
+    "#4353c2 #4350be #434eba #424bb5 #4148b0 #4145ab #4043a6 #4040a1 "
+    "#3f3d9c #3e3a96 #3d3791 #3c358b #3c3285 #3b2f7f #3a2c79 #392972 "
+    "#38266c #372365 #36215f #351e58 #341b51 #32184a #311542 #30123b "
 };
 
 static char HEX_Inferno_256_CMD[] = {
     "Inferno "
-    "#000003 #000004 #000006 #010007 #010109 #01010b #02010e #020210 "
-    "#030212 #040314 #040316 #050418 #06041b #07051d #08061f #090621 "
-    "#0a0723 #0b0726 #0d0828 #0e082a #0f092d #10092f #120a32 #130a34 "
-    "#140b36 #160b39 #170b3b #190b3e #1a0b40 #1c0c43 #1d0c45 #1f0c47 "
-    "#200c4a #220b4c #240b4e #260b50 #270b52 #290b54 #2b0a56 #2d0a58 "
-    "#2e0a5a #300a5c #32095d #34095f #350960 #370961 #390962 #3b0964 "
-    "#3c0965 #3e0966 #400966 #410967 #430a68 #450a69 #460a69 #480b6a "
-    "#4a0b6a #4b0c6b #4d0c6b #4f0d6c #500d6c #520e6c #530e6d #550f6d "
-    "#570f6d #58106d #5a116d #5b116e #5d126e #5f126e #60136e #62146e "
-    "#63146e #65156e #66156e #68166e #6a176e #6b176e #6d186e #6e186e "
-    "#70196e #72196d #731a6d #751b6d #761b6d #781c6d #7a1c6d #7b1d6c "
-    "#7d1d6c #7e1e6c #801f6b #811f6b #83206b #85206a #86216a #88216a "
-    "#892269 #8b2269 #8d2369 #8e2468 #902468 #912567 #932567 #952666 "
-    "#962666 #982765 #992864 #9b2864 #9c2963 #9e2963 #a02a62 #a12b61 "
-    "#a32b61 #a42c60 #a62c5f #a72d5f #a92e5e #ab2e5d #ac2f5c #ae305b "
-    "#af315b #b1315a #b23259 #b43358 #b53357 #b73456 #b83556 #ba3655 "
-    "#bb3754 #bd3753 #be3852 #bf3951 #c13a50 #c23b4f #c43c4e #c53d4d "
-    "#c73e4c #c83e4b #c93f4a #cb4049 #cc4148 #cd4247 #cf4446 #d04544 "
-    "#d14643 #d24742 #d44841 #d54940 #d64a3f #d74b3e #d94d3d #da4e3b "
-    "#db4f3a #dc5039 #dd5238 #de5337 #df5436 #e05634 #e25733 #e35832 "
-    "#e45a31 #e55b30 #e65c2e #e65e2d #e75f2c #e8612b #e9622a #ea6428 "
-    "#eb6527 #ec6726 #ed6825 #ed6a23 #ee6c22 #ef6d21 #f06f1f #f0701e "
-    "#f1721d #f2741c #f2751a #f37719 #f37918 #f47a16 #f57c15 #f57e14 "
-    "#f68012 #f68111 #f78310 #f7850e #f8870d #f8880c #f88a0b #f98c09 "
-    "#f98e08 #f99008 #fa9107 #fa9306 #fa9506 #fa9706 #fb9906 #fb9b06 "
-    "#fb9d06 #fb9e07 #fba007 #fba208 #fba40a #fba60b #fba80d #fbaa0e "
-    "#fbac10 #fbae12 #fbb014 #fbb116 #fbb318 #fbb51a #fbb71c #fbb91e "
-    "#fabb21 #fabd23 #fabf25 #fac128 #f9c32a #f9c52c #f9c72f #f8c931 "
-    "#f8cb34 #f8cd37 #f7cf3a #f7d13c #f6d33f #f6d542 #f5d745 #f5d948 "
-    "#f4db4b #f4dc4f #f3de52 #f3e056 #f3e259 #f2e45d #f2e660 #f1e864 "
-    "#f1e968 #f1eb6c #f1ed70 #f1ee74 #f1f079 #f1f27d #f2f381 #f2f485 "
-    "#f3f689 #f4f78d #f5f891 #f6fa95 #f7fb99 #f9fc9d #fafda0 #fcfea4 "
+    "#fcfea4 #fafda0 #f9fc9d #f7fb99 #f6fa95 #f5f891 #f4f78d #f3f689 "
+    "#f2f485 #f2f381 #f1f27d #f1f079 #f1ee74 #f1ed70 #f1eb6c #f1e968 "
+    "#f1e864 #f2e660 #f2e45d #f3e259 #f3e056 #f3de52 #f4dc4f #f4db4b "
+    "#f5d948 #f5d745 #f6d542 #f6d33f #f7d13c #f7cf3a #f8cd37 #f8cb34 "
+    "#f8c931 #f9c72f #f9c52c #f9c32a #fac128 #fabf25 #fabd23 #fabb21 "
+    "#fbb91e #fbb71c #fbb51a #fbb318 #fbb116 #fbb014 #fbae12 #fbac10 "
+    "#fbaa0e #fba80d #fba60b #fba40a #fba208 #fba007 #fb9e07 #fb9d06 "
+    "#fb9b06 #fb9906 #fa9706 #fa9506 #fa9306 #fa9107 #f99008 #f98e08 "
+    "#f98c09 #f88a0b #f8880c #f8870d #f7850e #f78310 #f68111 #f68012 "
+    "#f57e14 #f57c15 #f47a16 #f37918 #f37719 #f2751a #f2741c #f1721d "
+    "#f0701e #f06f1f #ef6d21 #ee6c22 #ed6a23 #ed6825 #ec6726 #eb6527 "
+    "#ea6428 #e9622a #e8612b #e75f2c #e65e2d #e65c2e #e55b30 #e45a31 "
+    "#e35832 #e25733 #e05634 #df5436 #de5337 #dd5238 #dc5039 #db4f3a "
+    "#da4e3b #d94d3d #d74b3e #d64a3f #d54940 #d44841 #d24742 #d14643 "
+    "#d04544 #cf4446 #cd4247 #cc4148 #cb4049 #c93f4a #c83e4b #c73e4c "
+    "#c53d4d #c43c4e #c23b4f #c13a50 #bf3951 #be3852 #bd3753 #bb3754 "
+    "#ba3655 #b83556 #b73456 #b53357 #b43358 #b23259 #b1315a #af315b "
+    "#ae305b #ac2f5c #ab2e5d #a92e5e #a72d5f #a62c5f #a42c60 #a32b61 "
+    "#a12b61 #a02a62 #9e2963 #9c2963 #9b2864 #992864 #982765 #962666 "
+    "#952666 #932567 #912567 #902468 #8e2468 #8d2369 #8b2269 #892269 "
+    "#88216a #86216a #85206a #83206b #811f6b #801f6b #7e1e6c #7d1d6c "
+    "#7b1d6c #7a1c6d #781c6d #761b6d #751b6d #731a6d #72196d #70196e "
+    "#6e186e #6d186e #6b176e #6a176e #68166e #66156e #65156e #63146e "
+    "#62146e #60136e #5f126e #5d126e #5b116e #5a116d #58106d #570f6d "
+    "#550f6d #530e6d #520e6c #500d6c #4f0d6c #4d0c6b #4b0c6b #4a0b6a "
+    "#480b6a #460a69 #450a69 #430a68 #410967 #400966 #3e0966 #3c0965 "
+    "#3b0964 #390962 #370961 #350960 #34095f #32095d #300a5c #2e0a5a "
+    "#2d0a58 #2b0a56 #290b54 #270b52 #260b50 #240b4e #220b4c #200c4a "
+    "#1f0c47 #1d0c45 #1c0c43 #1a0b40 #190b3e #170b3b #160b39 #140b36 "
+    "#130a34 #120a32 #10092f #0f092d #0e082a #0d0828 #0b0726 #0a0723 "
+    "#090621 #08061f #07051d #06041b #050418 #040316 #040314 #030212 "
+    "#020210 #02010e #01010b #010109 #010007 #000006 #000004 #000003 "
 };
 
 static char HEX_Magma_256_CMD[] = {
     "Magma "
-    "#000003 #000004 #000006 #010007 #010109 #01010b #02020d #02020f "
-    "#030311 #040313 #040415 #050417 #060519 #07051b #08061d #09071f "
-    "#0a0722 #0b0824 #0c0926 #0d0a28 #0e0a2a #0f0b2c #100c2f #110c31 "
-    "#120d33 #140d35 #150e38 #160e3a #170f3c #180f3f #1a1041 #1b1044 "
-    "#1c1046 #1e1049 #1f114b #20114d #221150 #231152 #251155 #261157 "
-    "#281159 #2a115c #2b115e #2d1060 #2f1062 #301065 #321067 #341068 "
-    "#350f6a #370f6c #390f6e #3b0f6f #3c0f71 #3e0f72 #400f73 #420f74 "
-    "#430f75 #450f76 #470f77 #481078 #4a1079 #4b1079 #4d117a #4f117b "
-    "#50127b #52127c #53137c #55137d #57147d #58157e #5a157e #5b167e "
-    "#5d177e #5e177f #60187f #61187f #63197f #651a80 #661a80 #681b80 "
-    "#691c80 #6b1c80 #6c1d80 #6e1e81 #6f1e81 #711f81 #731f81 #742081 "
-    "#762181 #772181 #792281 #7a2281 #7c2381 #7e2481 #7f2481 #812581 "
-    "#822581 #842681 #852681 #872781 #892881 #8a2881 #8c2980 #8d2980 "
-    "#8f2a80 #912a80 #922b80 #942b80 #952c80 #972c7f #992d7f #9a2d7f "
-    "#9c2e7f #9e2e7e #9f2f7e #a12f7e #a3307e #a4307d #a6317d #a7317d "
-    "#a9327c #ab337c #ac337b #ae347b #b0347b #b1357a #b3357a #b53679 "
-    "#b63679 #b83778 #b93778 #bb3877 #bd3977 #be3976 #c03a75 #c23a75 "
-    "#c33b74 #c53c74 #c63c73 #c83d72 #ca3e72 #cb3e71 #cd3f70 #ce4070 "
-    "#d0416f #d1426e #d3426d #d4436d #d6446c #d7456b #d9466a #da4769 "
-    "#dc4869 #dd4968 #de4a67 #e04b66 #e14c66 #e24d65 #e44e64 #e55063 "
-    "#e65162 #e75262 #e85461 #ea5560 #eb5660 #ec585f #ed595f #ee5b5e "
-    "#ee5d5d #ef5e5d #f0605d #f1615c #f2635c #f3655c #f3675b #f4685b "
-    "#f56a5b #f56c5b #f66e5b #f6705b #f7715b #f7735c #f8755c #f8775c "
-    "#f9795c #f97b5d #f97d5d #fa7f5e #fa805e #fa825f #fb8460 #fb8660 "
-    "#fb8861 #fb8a62 #fc8c63 #fc8e63 #fc9064 #fc9265 #fc9366 #fd9567 "
-    "#fd9768 #fd9969 #fd9b6a #fd9d6b #fd9f6c #fda16e #fda26f #fda470 "
-    "#fea671 #fea873 #feaa74 #feac75 #feae76 #feaf78 #feb179 #feb37b "
-    "#feb57c #feb77d #feb97f #febb80 #febc82 #febe83 #fec085 #fec286 "
-    "#fec488 #fec689 #fec78b #fec98d #fecb8e #fdcd90 #fdcf92 #fdd193 "
-    "#fdd295 #fdd497 #fdd698 #fdd89a #fdda9c #fddc9d #fddd9f #fddfa1 "
-    "#fde1a3 #fce3a5 #fce5a6 #fce6a8 #fce8aa #fceaac #fcecae #fceeb0 "
-    "#fcf0b1 #fcf1b3 #fcf3b5 #fcf5b7 #fbf7b9 #fbf9bb #fbfabd #fbfcbf "
+    "#fbfcbf #fbfabd #fbf9bb #fbf7b9 #fcf5b7 #fcf3b5 #fcf1b3 #fcf0b1 "
+    "#fceeb0 #fcecae #fceaac #fce8aa #fce6a8 #fce5a6 #fce3a5 #fde1a3 "
+    "#fddfa1 #fddd9f #fddc9d #fdda9c #fdd89a #fdd698 #fdd497 #fdd295 "
+    "#fdd193 #fdcf92 #fdcd90 #fecb8e #fec98d #fec78b #fec689 #fec488 "
+    "#fec286 #fec085 #febe83 #febc82 #febb80 #feb97f #feb77d #feb57c "
+    "#feb37b #feb179 #feaf78 #feae76 #feac75 #feaa74 #fea873 #fea671 "
+    "#fda470 #fda26f #fda16e #fd9f6c #fd9d6b #fd9b6a #fd9969 #fd9768 "
+    "#fd9567 #fc9366 #fc9265 #fc9064 #fc8e63 #fc8c63 #fb8a62 #fb8861 "
+    "#fb8660 #fb8460 #fa825f #fa805e #fa7f5e #f97d5d #f97b5d #f9795c "
+    "#f8775c #f8755c #f7735c #f7715b #f6705b #f66e5b #f56c5b #f56a5b "
+    "#f4685b #f3675b #f3655c #f2635c #f1615c #f0605d #ef5e5d #ee5d5d "
+    "#ee5b5e #ed595f #ec585f #eb5660 #ea5560 #e85461 #e75262 #e65162 "
+    "#e55063 #e44e64 #e24d65 #e14c66 #e04b66 #de4a67 #dd4968 #dc4869 "
+    "#da4769 #d9466a #d7456b #d6446c #d4436d #d3426d #d1426e #d0416f "
+    "#ce4070 #cd3f70 #cb3e71 #ca3e72 #c83d72 #c63c73 #c53c74 #c33b74 "
+    "#c23a75 #c03a75 #be3976 #bd3977 #bb3877 #b93778 #b83778 #b63679 "
+    "#b53679 #b3357a #b1357a #b0347b #ae347b #ac337b #ab337c #a9327c "
+    "#a7317d #a6317d #a4307d #a3307e #a12f7e #9f2f7e #9e2e7e #9c2e7f "
+    "#9a2d7f #992d7f #972c7f #952c80 #942b80 #922b80 #912a80 #8f2a80 "
+    "#8d2980 #8c2980 #8a2881 #892881 #872781 #852681 #842681 #822581 "
+    "#812581 #7f2481 #7e2481 #7c2381 #7a2281 #792281 #772181 #762181 "
+    "#742081 #731f81 #711f81 #6f1e81 #6e1e81 #6c1d80 #6b1c80 #691c80 "
+    "#681b80 #661a80 #651a80 #63197f #61187f #60187f #5e177f #5d177e "
+    "#5b167e #5a157e #58157e #57147d #55137d #53137c #52127c #50127b "
+    "#4f117b #4d117a #4b1079 #4a1079 #481078 #470f77 #450f76 #430f75 "
+    "#420f74 #400f73 #3e0f72 #3c0f71 #3b0f6f #390f6e #370f6c #350f6a "
+    "#341068 #321067 #301065 #2f1062 #2d1060 #2b115e #2a115c #281159 "
+    "#261157 #251155 #231152 #221150 #20114d #1f114b #1e1049 #1c1046 "
+    "#1b1044 #1a1041 #180f3f #170f3c #160e3a #150e38 #140d35 #120d33 "
+    "#110c31 #100c2f #0f0b2c #0e0a2a #0d0a28 #0c0926 #0b0824 #0a0722 "
+    "#09071f #08061d #07051b #060519 #050417 #040415 #040313 #030311 "
+    "#02020f #02020d #01010b #010109 #010007 #000006 #000004 #000003 "
 };
 
 static char HEX_Plasma_256_CMD[] = {
     "Plasma "
-    "#0c0786 #100787 #130689 #15068a #18068b #1b068c #1d068d #1f058e "
-    "#21058f #230590 #250591 #270592 #290593 #2b0594 #2d0494 #2f0495 "
-    "#310496 #330497 #340498 #360498 #380499 #3a049a #3b039a #3d039b "
-    "#3f039c #40039c #42039d #44039e #45039e #47029f #49029f #4a02a0 "
-    "#4c02a1 #4e02a1 #4f02a2 #5101a2 #5201a3 #5401a3 #5601a3 #5701a4 "
-    "#5901a4 #5a00a5 #5c00a5 #5e00a5 #5f00a6 #6100a6 #6200a6 #6400a7 "
-    "#6500a7 #6700a7 #6800a7 #6a00a7 #6c00a8 #6d00a8 #6f00a8 #7000a8 "
-    "#7200a8 #7300a8 #7500a8 #7601a8 #7801a8 #7901a8 #7b02a8 #7c02a7 "
-    "#7e03a7 #7f03a7 #8104a7 #8204a7 #8405a6 #8506a6 #8607a6 #8807a5 "
-    "#8908a5 #8b09a4 #8c0aa4 #8e0ca4 #8f0da3 #900ea3 #920fa2 #9310a1 "
-    "#9511a1 #9612a0 #9713a0 #99149f #9a159e #9b179e #9d189d #9e199c "
-    "#9f1a9b #a01b9b #a21c9a #a31d99 #a41e98 #a51f97 #a72197 #a82296 "
-    "#a92395 #aa2494 #ac2593 #ad2692 #ae2791 #af2890 #b02a8f #b12b8f "
-    "#b22c8e #b42d8d #b52e8c #b62f8b #b7308a #b83289 #b93388 #ba3487 "
-    "#bb3586 #bc3685 #bd3784 #be3883 #bf3982 #c03b81 #c13c80 #c23d80 "
-    "#c33e7f #c43f7e #c5407d #c6417c #c7427b #c8447a #c94579 #ca4678 "
-    "#cb4777 #cc4876 #cd4975 #ce4a75 #cf4b74 #d04d73 #d14e72 #d14f71 "
-    "#d25070 #d3516f #d4526e #d5536d #d6556d #d7566c #d7576b #d8586a "
-    "#d95969 #da5a68 #db5b67 #dc5d66 #dc5e66 #dd5f65 #de6064 #df6163 "
-    "#df6262 #e06461 #e16560 #e26660 #e3675f #e3685e #e46a5d #e56b5c "
-    "#e56c5b #e66d5a #e76e5a #e87059 #e87158 #e97257 #ea7356 #ea7455 "
-    "#eb7654 #ec7754 #ec7853 #ed7952 #ed7b51 #ee7c50 #ef7d4f #ef7e4e "
-    "#f0804d #f0814d #f1824c #f2844b #f2854a #f38649 #f38748 #f48947 "
-    "#f48a47 #f58b46 #f58d45 #f68e44 #f68f43 #f69142 #f79241 #f79341 "
-    "#f89540 #f8963f #f8983e #f9993d #f99a3c #fa9c3b #fa9d3a #fa9f3a "
-    "#faa039 #fba238 #fba337 #fba436 #fca635 #fca735 #fca934 #fcaa33 "
-    "#fcac32 #fcad31 #fdaf31 #fdb030 #fdb22f #fdb32e #fdb52d #fdb62d "
-    "#fdb82c #fdb92b #fdbb2b #fdbc2a #fdbe29 #fdc029 #fdc128 #fdc328 "
-    "#fdc427 #fdc626 #fcc726 #fcc926 #fccb25 #fccc25 #fcce25 #fbd024 "
-    "#fbd124 #fbd324 #fad524 #fad624 #fad824 #f9d924 #f9db24 #f8dd24 "
-    "#f8df24 #f7e024 #f7e225 #f6e425 #f6e525 #f5e726 #f5e926 #f4ea26 "
-    "#f3ec26 #f3ee26 #f2f026 #f2f126 #f1f326 #f0f525 #f0f623 #eff821 "
+    "#eff821 #f0f623 #f0f525 #f1f326 #f2f126 #f2f026 #f3ee26 #f3ec26 "
+    "#f4ea26 #f5e926 #f5e726 #f6e525 #f6e425 #f7e225 #f7e024 #f8df24 "
+    "#f8dd24 #f9db24 #f9d924 #fad824 #fad624 #fad524 #fbd324 #fbd124 "
+    "#fbd024 #fcce25 #fccc25 #fccb25 #fcc926 #fcc726 #fdc626 #fdc427 "
+    "#fdc328 #fdc128 #fdc029 #fdbe29 #fdbc2a #fdbb2b #fdb92b #fdb82c "
+    "#fdb62d #fdb52d #fdb32e #fdb22f #fdb030 #fdaf31 #fcad31 #fcac32 "
+    "#fcaa33 #fca934 #fca735 #fca635 #fba436 #fba337 #fba238 #faa039 "
+    "#fa9f3a #fa9d3a #fa9c3b #f99a3c #f9993d #f8983e #f8963f #f89540 "
+    "#f79341 #f79241 #f69142 #f68f43 #f68e44 #f58d45 #f58b46 #f48a47 "
+    "#f48947 #f38748 #f38649 #f2854a #f2844b #f1824c #f0814d #f0804d "
+    "#ef7e4e #ef7d4f #ee7c50 #ed7b51 #ed7952 #ec7853 #ec7754 #eb7654 "
+    "#ea7455 #ea7356 #e97257 #e87158 #e87059 #e76e5a #e66d5a #e56c5b "
+    "#e56b5c #e46a5d #e3685e #e3675f #e26660 #e16560 #e06461 #df6262 "
+    "#df6163 #de6064 #dd5f65 #dc5e66 #dc5d66 #db5b67 #da5a68 #d95969 "
+    "#d8586a #d7576b #d7566c #d6556d #d5536d #d4526e #d3516f #d25070 "
+    "#d14f71 #d14e72 #d04d73 #cf4b74 #ce4a75 #cd4975 #cc4876 #cb4777 "
+    "#ca4678 #c94579 #c8447a #c7427b #c6417c #c5407d #c43f7e #c33e7f "
+    "#c23d80 #c13c80 #c03b81 #bf3982 #be3883 #bd3784 #bc3685 #bb3586 "
+    "#ba3487 #b93388 #b83289 #b7308a #b62f8b #b52e8c #b42d8d #b22c8e "
+    "#b12b8f #b02a8f #af2890 #ae2791 #ad2692 #ac2593 #aa2494 #a92395 "
+    "#a82296 #a72197 #a51f97 #a41e98 #a31d99 #a21c9a #a01b9b #9f1a9b "
+    "#9e199c #9d189d #9b179e #9a159e #99149f #9713a0 #9612a0 #9511a1 "
+    "#9310a1 #920fa2 #900ea3 #8f0da3 #8e0ca4 #8c0aa4 #8b09a4 #8908a5 "
+    "#8807a5 #8607a6 #8506a6 #8405a6 #8204a7 #8104a7 #7f03a7 #7e03a7 "
+    "#7c02a7 #7b02a8 #7901a8 #7801a8 #7601a8 #7500a8 #7300a8 #7200a8 "
+    "#7000a8 #6f00a8 #6d00a8 #6c00a8 #6a00a7 #6800a7 #6700a7 #6500a7 "
+    "#6400a7 #6200a6 #6100a6 #5f00a6 #5e00a5 #5c00a5 #5a00a5 #5901a4 "
+    "#5701a4 #5601a3 #5401a3 #5201a3 #5101a2 #4f02a2 #4e02a1 #4c02a1 "
+    "#4a02a0 #49029f #47029f #45039e #44039e #42039d #40039c #3f039c "
+    "#3d039b #3b039a #3a049a #380499 #360498 #340498 #330497 #310496 "
+    "#2f0495 #2d0494 #2b0594 #290593 #270592 #250591 #230590 #21058f "
+    "#1f058e #1d068d #1b068c #18068b #15068a #130689 #100787 #0c0786 "
 };
 
 static char HEX_Viridis_256_CMD[] = {
     "Viridis "
-    "#440154 #440255 #440357 #450558 #45065a #45085b #46095c #460b5e "
-    "#460c5f #460e61 #470f62 #471163 #471265 #471466 #471567 #471669 "
-    "#47186a #48196b #481a6c #481c6e #481d6f #481e70 #482071 #482172 "
-    "#482273 #482374 #472575 #472676 #472777 #472878 #472a79 #472b7a "
-    "#472c7b #462d7c #462f7c #46307d #46317e #45327f #45347f #453580 "
-    "#453681 #443781 #443982 #433a83 #433b83 #433c84 #423d84 #423e85 "
-    "#424085 #414186 #414286 #404387 #404487 #3f4587 #3f4788 #3e4888 "
-    "#3e4989 #3d4a89 #3d4b89 #3d4c89 #3c4d8a #3c4e8a #3b508a #3b518a "
-    "#3a528b #3a538b #39548b #39558b #38568b #38578c #37588c #37598c "
-    "#365a8c #365b8c #355c8c #355d8c #345e8d #345f8d #33608d #33618d "
-    "#32628d #32638d #31648d #31658d #31668d #30678d #30688d #2f698d "
-    "#2f6a8d #2e6b8e #2e6c8e #2e6d8e #2d6e8e #2d6f8e #2c708e #2c718e "
-    "#2c728e #2b738e #2b748e #2a758e #2a768e #2a778e #29788e #29798e "
-    "#287a8e #287a8e #287b8e #277c8e #277d8e #277e8e #267f8e #26808e "
-    "#26818e #25828e #25838d #24848d #24858d #24868d #23878d #23888d "
-    "#23898d #22898d #228a8d #228b8d #218c8d #218d8c #218e8c #208f8c "
-    "#20908c #20918c #1f928c #1f938b #1f948b #1f958b #1f968b #1e978a "
-    "#1e988a #1e998a #1e998a #1e9a89 #1e9b89 #1e9c89 #1e9d88 #1e9e88 "
-    "#1e9f88 #1ea087 #1fa187 #1fa286 #1fa386 #20a485 #20a585 #21a685 "
-    "#21a784 #22a784 #23a883 #23a982 #24aa82 #25ab81 #26ac81 #27ad80 "
-    "#28ae7f #29af7f #2ab07e #2bb17d #2cb17d #2eb27c #2fb37b #30b47a "
-    "#32b57a #33b679 #35b778 #36b877 #38b976 #39b976 #3bba75 #3dbb74 "
-    "#3ebc73 #40bd72 #42be71 #44be70 #45bf6f #47c06e #49c16d #4bc26c "
-    "#4dc26b #4fc369 #51c468 #53c567 #55c666 #57c665 #59c764 #5bc862 "
-    "#5ec961 #60c960 #62ca5f #64cb5d #67cc5c #69cc5b #6bcd59 #6dce58 "
-    "#70ce56 #72cf55 #74d054 #77d052 #79d151 #7cd24f #7ed24e #81d34c "
-    "#83d34b #86d449 #88d547 #8bd546 #8dd644 #90d643 #92d741 #95d73f "
-    "#97d83e #9ad83c #9dd93a #9fd938 #a2da37 #a5da35 #a7db33 #aadb32 "
-    "#addc30 #afdc2e #b2dd2c #b5dd2b #b7dd29 #bade27 #bdde26 #bfdf24 "
-    "#c2df22 #c5df21 #c7e01f #cae01e #cde01d #cfe11c #d2e11b #d4e11a "
-    "#d7e219 #dae218 #dce218 #dfe318 #e1e318 #e4e318 #e7e419 #e9e419 "
-    "#ece41a #eee51b #f1e51c #f3e51e #f6e61f #f8e621 #fae622 #fde724 "
+    "#fde724 #fae622 #f8e621 #f6e61f #f3e51e #f1e51c #eee51b #ece41a "
+    "#e9e419 #e7e419 #e4e318 #e1e318 #dfe318 #dce218 #dae218 #d7e219 "
+    "#d4e11a #d2e11b #cfe11c #cde01d #cae01e #c7e01f #c5df21 #c2df22 "
+    "#bfdf24 #bdde26 #bade27 #b7dd29 #b5dd2b #b2dd2c #afdc2e #addc30 "
+    "#aadb32 #a7db33 #a5da35 #a2da37 #9fd938 #9dd93a #9ad83c #97d83e "
+    "#95d73f #92d741 #90d643 #8dd644 #8bd546 #88d547 #86d449 #83d34b "
+    "#81d34c #7ed24e #7cd24f #79d151 #77d052 #74d054 #72cf55 #70ce56 "
+    "#6dce58 #6bcd59 #69cc5b #67cc5c #64cb5d #62ca5f #60c960 #5ec961 "
+    "#5bc862 #59c764 #57c665 #55c666 #53c567 #51c468 #4fc369 #4dc26b "
+    "#4bc26c #49c16d #47c06e #45bf6f #44be70 #42be71 #40bd72 #3ebc73 "
+    "#3dbb74 #3bba75 #39b976 #38b976 #36b877 #35b778 #33b679 #32b57a "
+    "#30b47a #2fb37b #2eb27c #2cb17d #2bb17d #2ab07e #29af7f #28ae7f "
+    "#27ad80 #26ac81 #25ab81 #24aa82 #23a982 #23a883 #22a784 #21a784 "
+    "#21a685 #20a585 #20a485 #1fa386 #1fa286 #1fa187 #1ea087 #1e9f88 "
+    "#1e9e88 #1e9d88 #1e9c89 #1e9b89 #1e9a89 #1e998a #1e998a #1e988a "
+    "#1e978a #1f968b #1f958b #1f948b #1f938b #1f928c #20918c #20908c "
+    "#208f8c #218e8c #218d8c #218c8d #228b8d #228a8d #22898d #23898d "
+    "#23888d #23878d #24868d #24858d #24848d #25838d #25828e #26818e "
+    "#26808e #267f8e #277e8e #277d8e #277c8e #287b8e #287a8e #287a8e "
+    "#29798e #29788e #2a778e #2a768e #2a758e #2b748e #2b738e #2c728e "
+    "#2c718e #2c708e #2d6f8e #2d6e8e #2e6d8e #2e6c8e #2e6b8e #2f6a8d "
+    "#2f698d #30688d #30678d #31668d #31658d #31648d #32638d #32628d "
+    "#33618d #33608d #345f8d #345e8d #355d8c #355c8c #365b8c #365a8c "
+    "#37598c #37588c #38578c #38568b #39558b #39548b #3a538b #3a528b "
+    "#3b518a #3b508a #3c4e8a #3c4d8a #3d4c89 #3d4b89 #3d4a89 #3e4989 "
+    "#3e4888 #3f4788 #3f4587 #404487 #404387 #414286 #414186 #424085 "
+    "#423e85 #423d84 #433c84 #433b83 #433a83 #443982 #443781 #453681 "
+    "#453580 #45347f #45327f #46317e #46307d #462f7c #462d7c #472c7b "
+    "#472b7a #472a79 #472878 #472777 #472676 #472575 #482374 #482273 "
+    "#482172 #482071 #481e70 #481d6f #481c6e #481a6c #48196b #47186a "
+    "#471669 #471567 #471466 #471265 #471163 #470f62 #460e61 #460c5f "
+    "#460b5e #46095c #45085b #45065a #450558 #440357 #440255 #440154 "
 };
 
 
