@@ -614,8 +614,9 @@ if __name__ == "__main__":
     # --------------------------------------------------------------------
 
     # QC block: "vstat"
-    # item    : corr maps (rest/non-task FMRI): seedbased corr 
-    if not(DO_VSTAT_TASK) :               # only done in resting/non-task cases
+    # item    : corr maps (rest/non-task FMRI): seedbased corr in vol dset
+    if not(DO_VSTAT_TASK) and \
+       not(lat.check_if_niml_dset(ap_ssdict, 'errts_dset')) :
         # mirror same logic as task (above) for deciding ulay/olay
         DO_VSTAT_SEED_REST = 0
 
@@ -932,7 +933,7 @@ if __name__ == "__main__":
 
     # not currently a uvar, check for known dir name in AP results
     # dir; check for certain 'automatic' stats files that do not have
-    # HTML encoding already (and are not WB ones)
+    # HTML encoding already (or brain in suffix)
     all_fname = glob.glob('tsnr_stats_regress/stats_auto_*.txt')
     for fname in all_fname :
         if fname.endswith('_brain.txt') or fname.endswith('eval_html.txt') :
@@ -1080,6 +1081,36 @@ if __name__ == "__main__":
 
     # --------------------------------------------------------------------
 
+    # QC block: "warns"
+    # item    : ROI stats for TSNR (final) via compute_ROI_stats.tcsh
+
+    # not currently a uvar, check for known dir name in AP results
+    # dir; check for certain 'user' stats files that do not have
+    # HTML encoding already 
+    all_fname = glob.glob('tsnr_stats_regress/stats_user_*.txt')
+    for fname in all_fname :
+        if fname.endswith('eval_html.txt') :
+            _tmp = all_fname.remove(fname)
+    all_fname.sort()
+
+    if len(all_fname) :
+        ban      = lat.bannerize('check TSNR ROI stats (for warns block)')
+        for fname in all_fname:
+            # make string tag for this; we know that it starts with
+            # 'tsnr_stats_regress/stats_user_' and ends with '.txt',
+            # by definition (and not ('eval_html.txt'); so, remove
+            # those known prefix and suffix
+            flabel   = "roi_tsnr_warns_" 
+            if len(fname) > 34 :    flabel+= fname[30:-4]
+            else:                   flabel+= str(idx)
+
+            obase    = 'qc_{:02d}'.format(idx)
+            cmd      = lat.apqc_regr_roi_stats( ap_ssdict, obase, fname,
+                                                "warns", flabel )
+            idx     += 1
+
+    # --------------------------------------------------------------------
+
     # QC block: "qsumm"
     # item    : quant output of @ss_review_basic
 
